@@ -5,6 +5,24 @@
 #include <hmm/count_mers.h>
 #include "test.h"
 
+namespace boost {
+    void
+    assertion_failed_msg(
+        char const * expr,
+        char const * msg,
+        char const * function,
+        char const * file,
+        long line
+    ) {
+        std::cerr
+            << file << ":" << line
+            << ", " << function << "()" 
+            << "BOOST_ASSERT_MSG(" << expr << ") failed, \""
+            << msg << "\"\n";
+    }
+}
+
+
 using namespace hmm;
 
 struct output
