@@ -73,7 +73,7 @@ expose_em() {
 	em_descender_class.def_readwrite( "log_delta_factor", &em_t::log_delta_factor, "The amount by which we change log delta when we see the estimation of c_wb is too low." );
 	em_descender_class.def_readwrite( "log_delta_adjustment_max", &em_t::log_delta_adjustment_max, "The largest adjustment to log delta we allow." );
 	em_descender_class.def_readwrite( "log_delta_adjustment", &em_t::log_delta_adjustment, "An adjustment we make to log delta for the next iteration after seeing the actual value of c_wb. This can change every iteration." );
-	em_descender_class.def_readwrite( "log_delta", &em_t::log_delta, "Threshold on log expected Z_n." );
+	em_descender_class.def_readwrite( "llr_threshold", &em_t::llr_threshold, "Threshold on log likelihood ratio." );
 	em_descender_class.def_readwrite( "epsilon", &em_t::epsilon, "Allowed error in f_wb." );
 	em_descender_class.def_readwrite( "wnsites", &em_t::wnsites, "Weight on number of sites. Used when updating lambda." );
 	em_descender_class.def_readwrite( "using_sparse_Z", &em_t::using_sparse_Z, "Use sparse data structure to store Z." );
